==> react-virtualized-tree-1.0.0.tgz: package/es/selectors/nodes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { createSelector } from 'reselect';
import { UPDATE_TYPE } from '../contants';

export var getNodeRenderOptions = createSelector(function (node) {
  return (node.state || {}).expanded;
}, function (node) {
  return (node.state || {}).favorite;
}, function (node) {
  return (node.state || {}).deletable;
}, function (node) {
  return node.children;
}, function (expanded, favorite, deletable) {
  var children = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  return {
    hasChildren: !!children.length,
    isExpanded: !!expanded,
    isFavorite: !!favorite,
    isDeletable: !!deletable
  };
});

export var replaceNodeFromTree = function replaceNodeFromTree(nodes, updatedNode) {
  return nodes.map(function (node) {
    if (node.id === updatedNode.id) {
      return updatedNode;
    }

    if (node.children) {
      return _extends({}, node, { children: replaceNodeFromTree(node.children, updatedNode) });
    }

    return node;
  });
};

var findNodeOnTree = function findNodeOnTree(parents, parentNode, id) {
  if (!parents.length) {
    return {
      node: parentNode.children.find(function (n) {
        return n.id === id;
      }),
      parent: parentNode
    };
  }

  var nextParent = parents[0];


  return findNodeOnTree(parents.slice(1), parentNode.children.find(function (n) {
    return n.id === nextParent;
  }), id);
};

var isNodeInTreeRoot = function isNodeInTreeRoot(n) {
  return n.id === undefined;
};

export var deleteNodeFromTree = function deleteNodeFromTree(nodes, deletedNode) {
  var _findNodeOnTree = findNodeOnTree(deletedNode.parents, { children: nodes }, deletedNode.id),
      parent = _findNodeOnTree.parent;

  var childIndex = parent.children.findIndex(function (c) {
    return c.id === deletedNode.id;
  });

  if (isNodeInTreeRoot(parent)) {
    return [].concat(nodes.slice(0, childIndex), nodes.slice(childIndex + 1));
  }

  return replaceNodeFromTree(nodes, _extends({}, parent, {
    children: [].concat(parent.children.slice(0, childIndex), parent.children.slice(childIndex + 1))
  }));
};

export var udpateNode = function udpateNode(originalNode, newState) {
  return {
    node: _extends({}, originalNode, {
      state: _extends({}, originalNode.state, newState)
    }),
    type: UPDATE_TYPE.UPDATE
  };
};

export var deleteNode = function deleteNode(node) {
  return {
    node: node,
    type: UPDATE_TYPE.DELETE
  };
};

export var addNode = function addNode(node) {
  return {
    node: node,
    type: UPDATE_TYPE.ADD
  };
};

==> react-virtualized-tree-1.2.4.tgz: package/es/selectors/nodes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { createSelector } from 'reselect';
import { omit } from 'lodash';

import { UPDATE_TYPE } from '../contants';

export var getNodeRenderOptions = createSelector(function (node) {
  return (node.state || {}).expanded;
}, function (node) {
  return (node.state || {}).favorite;
}, function (node) {
  return (node.state || {}).deletable;
}, function (node) {
  return node.children;
}, function (expanded, favorite, deletable) {
  var children = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  return {
    hasChildren: !!children.length,
    isExpanded: !!expanded,
    isFavorite: !!favorite,
    isDeletable: !!deletable
  };
});

var PICK_CHILDREN_FROM = {
  ORIGIN: 0,
  CURRENT: 1
};

var FLATTEN_TREE_PROPERTIES = ['deepness', 'parents'];

export var replaceNodeFromTree = function replaceNodeFromTree(nodes, updatedNode) {
  var pickChildrenFrom = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : PICK_CHILDREN_FROM.ORIGIN;

  return nodes.map(function (node) {
    var children = node.children ? replaceNodeFromTree(node.children, updatedNode, pickChildrenFrom) : node.children;

    if (node.id === updatedNode.id) {
      return _extends({}, omit(updatedNode, FLATTEN_TREE_PROPERTIES), pickChildrenFrom === PICK_CHILDREN_FROM.ORIGIN && children ? { children: children } : {});
    }

    return _extends({}, node, children ? { children: children } : {});
  });
};

var findNodeOnTree = function findNodeOnTree(parents, parentNode, id) {
  if (!parents.length) {
    return {
      node: parentNode.children.find(function (n) {
        return n.id === id;
      }),
      parent: parentNode
    };
  }

  var nextParent = parents[0];


  return findNodeOnTree(parents.slice(1), parentNode.children.find(function (n) {
    return n.id === nextParent;
  }), id);
};

var isNodeInTreeRoot = function isNodeInTreeRoot(n) {
  return n.id === undefined;
};

export var deleteNodeFromTree = function deleteNodeFromTree(nodes, deletedNode) {
  var _findNodeOnTree = findNodeOnTree(deletedNode.parents, { children: nodes }, deletedNode.id),
      parent = _findNodeOnTree.parent;

  var childIndex = parent.children.findIndex(function (c) {
    return c.id === deletedNode.id;
  });

  if (isNodeInTreeRoot(parent)) {
    return [].concat(nodes.slice(0, childIndex), nodes.slice(childIndex + 1));
  }

  return replaceNodeFromTree(nodes, _extends({}, parent, {
    children: [].concat(parent.children.slice(0, childIndex), parent.children.slice(childIndex + 1))
  }), PICK_CHILDREN_FROM.CURRENT);
};

export var udpateNode = function udpateNode(originalNode, newState) {
  return {
    node: _extends({}, originalNode, {
      state: _extends({}, originalNode.state, newState)
    }),
    type: UPDATE_TYPE.UPDATE
  };
};

export var deleteNode = function deleteNode(node) {
  return {
    node: node,
    type: UPDATE_TYPE.DELETE
  };
};

export var addNode = function addNode(node) {
  return {
    node: node,
    type: UPDATE_TYPE.ADD
  };
};
